<?php

namespace Drupal\cached_computed_field_test\EventSubscriber;

use Drupal\cached_computed_field\Event\RefreshExpiredFieldEventInterface;
use Drupal\cached_computed_field\EventSubscriber\RefreshExpiredFieldSubscriberBase;

/**
 * A test implementation of an event subscriber that refreshes expired fields.
 *
 * @deprecated
 *   To be replaced with a subscriber extending the base class that supports
 *   processing multiple items.
 */
class RefreshExpiredIntegerFieldSubscriber extends RefreshExpiredFieldSubscriberBase {

  /**
   * {@inheritdoc}
   */
  public function refreshExpiredField(RefreshExpiredFieldEventInterface $event) {
    $entity = $this->getEntity($event);
    $entity->set($event->getFieldName(), [
      // Set the value to '100' so we can recognize it has been processed.
      'value' => 100,
      // Don't set the expiration date so that this is immediately marked as
      // expired. We don't want to wait for time to pass in tests.
      'expire' => NULL,
    ]);
    $entity->save();

    // Wait for one second, to simulate a slow API call.
    sleep(1);
  }

  /**
   * {@inheritdoc}
   */
  public function fieldNeedsRefresh(RefreshExpiredFieldEventInterface $event) {
    // Avoid using a time based expiration so we don't need to wait for precious
    // seconds to pass during tests. Our test fields are always ready to be
    // refreshed.
    return TRUE;
  }

}
